@@ -1,6 +1,6 @@
 # coding: utf-8
 
-from __future__ import division, print_function
+
 
 # Standard library
 from collections import namedtuple, OrderedDict
@@ -178,7 +178,7 @@ class PhaseSpacePosition(object):
         # make sure shape is the same
         if pos.shape != vel.shape:
             raise ValueError("Position and velocity must have the same shape "
-                             "{} vs {}".format(pos.shape, vel.shape))
+                             "{0} vs {0}".format(pos.shape, vel.shape))
 
         from ..potential.frame import FrameBase
         if frame is not None and not isinstance(frame, FrameBase):
@@ -438,8 +438,8 @@ class PhaseSpacePosition(object):
                           "using the `galcen_v_sun` argument.",
                           DeprecationWarning)
 
-        if (getattr(self, self.pos_components.keys()[0]).unit == u.one or
-                getattr(self, self.vel_components.keys()[0]).unit == u.one):
+        if (getattr(self, list(self.pos_components.keys())[0]).unit == u.one or
+                getattr(self, list(self.vel_components.keys())[0]).unit == u.one):
             raise u.UnitConversionError("Position and velocity must have "
                                         "dimensioned units to convert to a "
                                         "coordinate frame.")
@@ -558,11 +558,11 @@ class PhaseSpacePosition(object):
             frame_group.attrs['class'] = self.frame.__class__.__name__
 
             units = [str(x).encode('utf8')
-                     for x in self.frame.units.to_dict().values()]
+                     for x in list(self.frame.units.to_dict().values())]
             frame_group.create_dataset('units', data=units)
 
             d = frame_group.create_group('parameters')
-            for k, par in self.frame.parameters.items():
+            for k, par in list(self.frame.parameters.items()):
                 quantity_to_hdf5(d, k, par)
 
         cart = self.represent_as('cartesian')
@@ -834,7 +834,7 @@ class PhaseSpacePosition(object):
             'autolim': False
         }
 
-        for k,v in default_kwargs.items():
+        for k,v in list(default_kwargs.items()):
             kwargs[k] = kwargs.get(k, v)
 
         fig = plot_projections(x, **kwargs)
@@ -883,3 +883,4 @@ class CartesianPhaseSpacePosition(PhaseSpacePosition):
                       DeprecationWarning)
 
         super(CartesianPhaseSpacePosition, self).__init__(pos, vel, frame=frame)
+
